<?php
/*
 * Plugin Name: RebelMouse plugin light 
 * Plugin URI: http://www.rebelmouse.com
 * Description: Add your RebelMouse to your blog. Add and edit in the widgets tab of WordPress or using shortcode.
 * Version: 1.1.1
 * Author: Francisco Lavin
 * Author URI: http://www.rebelmouse.com/flavin
 *License: GPLv2 or later
 */

/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

/**
 * Register the Widget
 */
add_action( 'widgets_init', create_function( '', 'register_widget("rebelmouse_widget");' ) );

/**
 * Create the widget class and extend from the WP_Widget
 */
 class Rebelmouse_Widget extends WP_Widget {

	/**
	 * Set the widget defaults
	 */
	private $widget_title = "RebelMouse Widget";
	private $site_name = "rebelmouse";
	private $cols = 1;
	private $scroll = "auto";

	private $width = "";
	private $height = "";

	private $skip = array();
	private $show_about = "true";
	private	$show_following = "false";
	private	$show_also_in_rm = "true";
	private	$show_share = "true";

	/**
	 * Register widget with WordPress.
	 */
	public function __construct() {

		parent::__construct(
			'Rebelmouse_Widget',// Base ID
			'RebelMouse ',// Name
			array(
				'classname'		=>	'Rebelmouse_Widget',
				'description'	=>	__('A widget to add your rebelmouse stream.', 'framework')
			)
		);

	} // end constructor

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$this->widget_title = apply_filters('widget_title', $instance['title'] );

		$this->site_name = $instance['site_name'];
		$this->cols = $instance['cols'];
		$this->scroll = $instance['scroll'];
		$this->height = $instance['height'];


        $skip = ($instance['show_about'] == "1" ?  "" : "about-site,");
        $skip .= ($instance['show_following'] == "1" ? "" : "following," );
        $skip .= ($instance['show_also_in_rm'] == "1" ? "" : "also-on-rm," );
        $skip .= ($instance['show_share'] == "1" ? "" : "share-frontpage" );

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $this->widget_title )
			echo $before_title . $this->widget_title . $after_title;

		/* RebelMouse Render*/
        $this->render( array('site_name' => $this->site_name
                            , 'cols' => $this->cols, 'skip' => $skip, 'width' => $this->width
                            , 'scroll' => $this->scroll, 'height' => $this->height ) );

		/* After widget (defined by themes). */
		echo $after_widget;
	}

    public function render( $args ) {
        $r = wp_parse_args( $args
                            , array(
                                    'site_name' => 'rebelmouse'
                                    ,'cols' => '1'
                                    ,'skip' => ''
                                    ,'width'=> ''
                                    ,'height' => '0'
                                    ,'scroll' => 'auto'
                                    ) );

        $r['cols'] = intval( $r['cols'] );
        if ( empty( $r['cols'] ) )
            $r['cols'] = 1;
        elseif ( $r['cols'] > 5 )
            $r['cols'] = 5;
                
        if ( empty( $r['height'] ) ) {
            $is_flexible = true;
            $r['height'] = '1500px';
        } else {
            $is_flexible = false;
            $r['height'] .= 'px';
        }

        if ( empty( $r['width'] ) )
            $r['width'] = '100%';
            //$r['width'] = ($r['cols']*257).'px';
        elseif ( ! rm_endsWith( $r['width'], '%') && ! rm_endsWith( $r['width'], 'px') )
            $r['width'] .= 'px';

        $params = 'embedded=1';

        //$params .= '&cols=' . $r['cols'];

        if ( !empty( $r['skip'] ) )
            $params .= '&skip=' . $r['skip'];

        $scrolling = '';
        if ( $r['scroll'] === 'no' )
            $scrolling = 'scrolling="no"';
        elseif ( $r['scroll'] === 'yes' )
            $scrolling = 'scrolling="yes"';

        ?>

        <style>.rebelmouse-container{ width:100%;text-align:center;overflow-x: hidden;overflow-y: hidden;}#rebelmouse-embed { overflow-x: hidden; }iframe::-webkit-scrollbar { display: none; } </style>
        <div class="rebelmouse-container">
            <iframe id="rebelmouse-embed" allowtransparency="true" frameborder="0" <?php echo $scrolling; ?>
                height="<?php echo $r['height']; ?>" width="<?php echo $r['width']; ?>"
                src="http://www.rebelmouse.com/<?php echo $r['site_name'] ?>/?<?php echo $params; ?>"></iframe>
            <?php if ($is_flexible) { ?>
            <script type="text/javascript">!function(){var e=this,t=e.document,n=t.getElementById("rebelmouse-embed").contentWindow,r=function(n,r,i){typeof e.addEventListener=="function"?n.addEventListener(r,i,!1):typeof t.attachEvent=="function"?n.attachEvent("on"+r,i):n["on"+r]=i};r(e,"message",function(e){t.getElementById("rebelmouse-embed").style.height=e.data+"px"}),r(e,"scroll",function(){t.height-t.body.scrollTop-e.innerHeight<600&&n.postMessage("get_new_post","*")})}()</script>
            <?php } ?>
        </div>
        <?php
    }

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['site_name'] = strip_tags( $new_instance['site_name'] );
		$instance['cols'] = strip_tags( $new_instance['cols'] );
		$instance['scroll'] = strip_tags( $new_instance['scroll'] );

		//$instance['width'] = strip_tags( $new_instance['width'] );
		$instance['height'] = strip_tags( $new_instance['height'] );

		$instance['show_about'] = (bool)$new_instance['show_about'];
		$instance['show_following'] = (bool)$new_instance['show_following'];
		$instance['show_also_in_rm'] = (bool)$new_instance['show_also_in_rm'];
		$instance['show_share'] = (bool)$new_instance['show_share'];

		return $instance;
	}

	/**
	 * Create the form for the Widget admin
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array(
		'title' => $this->widget_title,
		'site_name' => $this->site_name,
		'cols' => $this->cols,
		'scroll' => $this->scroll,

		'width' => $this->width,
		'height' => $this->height,
		'show_about' => $this->show_about,
		'show_following' => $this->show_following,
		'show_also_in_rm' => $this->show_also_in_rm,
		'show_share' => $this->show_share,
        'border_color' => $this->border_color,

		);

		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

        <!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title', 'framework') ?>: </label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<!-- Page name: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'site_name' ); ?>"><?php _e('Site name', 'framework') ?>: </label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'site_name' ); ?>" name="<?php echo $this->get_field_name( 'site_name' ); ?>" value="<?php echo $instance['site_name']; ?>" />
            <br><small>default: rebelmouse</small>
		</p>

        <?php /*
		<!-- Width: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>"><?php _e('Width', 'framework') ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'width' ); ?>" name="<?php echo $this->get_field_name( 'width' ); ?>" value="<?php echo $instance['width']; ?>" />
		</p>
         */?>

		<!-- Show About: Checkbox -->
        <p>
			<label><?php _e('Show this site modules', 'framework') ?>: </label>
            <br>
			<input type="checkbox" id="<?php echo $this->get_field_id( 'show_about' ); ?>" name="<?php echo $this->get_field_name( 'show_about' ); ?>" value="1" <?php echo ($instance['show_about'] == "true" ? "checked='checked'" : ""); ?> />
			<label for="<?php echo $this->get_field_id( 'show_about' ); ?>"><?php _e('About', 'framework') ?></label>
		<br>

		<!-- Show Following: Checkbox -->
			<input type="checkbox" id="<?php echo $this->get_field_id( 'show_following' ); ?>" name="<?php echo $this->get_field_name( 'show_following' ); ?>" value="1" <?php echo ($instance['show_following'] == "true" ? "checked='checked'" : ""); ?> />
			<label for="<?php echo $this->get_field_id( 'show_following' ); ?>"><?php _e('Following', 'framework') ?></label>
		<br>

		<!-- Show Also in RebelMouse: Checkbox -->
			<input type="checkbox" id="<?php echo $this->get_field_id( 'show_also_in_rm' ); ?>" name="<?php echo $this->get_field_name( 'show_also_in_rm' ); ?>" value="1" <?php echo ($instance['show_also_in_rm'] == "true" ? "checked='checked'" : ""); ?> />
			<label for="<?php echo $this->get_field_id( 'show_also_in_rm' ); ?>"><?php _e('Also In RebelMouse', 'framework') ?></label>
		<br>
		</p>

		<p>
        <strong>Advance settings:</strong>
		</p>
        
		<!-- Scroll -->
		<p>
			<label for="<?php echo $this->get_field_id( 'scroll' ); ?>"><?php _e('Scroll', 'framework'); ?>: </label><br>
            <select id="<?php echo $this->get_field_id( 'scroll' ); ?>" name="<?php echo $this->get_field_name( 'scroll' ); ?>">
                <option value="auto"  <?php echo ('auto' == $instance['scroll'] || empty($instance['scroll']))? 'selected="selected"':'';  ?>>auto</option>
                <option value="no" <?php echo ('no' == $instance['scroll'])? 'selected="selected"':'';  ?>>no</option>
                <option value="yes" <?php echo ('yes' == $instance['scroll'])? 'selected="selected"':'';  ?>>yes</option>
            </select>
            <br><small>default: auto</small>
		</p>

		<!-- Height: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'height' ); ?>"><?php _e('Height', 'framework') ?>: </label>
			<input type="text" id="<?php echo $this->get_field_id( 'height' ); ?>" name="<?php echo $this->get_field_name( 'height' ); ?>" value="<?php echo $instance['height']; ?>" size="5" />px
			<br><small>default: emtpy this set autoadjustable</small>
		</p>

	<?php
	}
 }


/**
 * Display the embed of rebelmouse stream
 *
 * The list of arguments is below:
 *     'site_name' (string) - You rebelmouse site name
 *     'cols' (int) - Number of columns to show (the final width is 257px for columns number)
 *     'skip' (String) - Element to hide in the stream: about-site, following, also-on-rm, share-frontpage
 *     'height' (int) - height of the iframe
 *
 * @param string|array $args Optional. Override the defaults.
 */ 
function rebelmouse_embed( $args ) {
    $rm_widget = new Rebelmouse_Widget();
    $rm_widget->render( $args );
}

/**
 * Shortcode to diplay rebelmouse in your site.
 * 
 * The list of arguments is below:
 *     'site_name' (string) - You rebelmouse site name
 *                    Default: rebelmouse
 *     'skip' (String) - Element to hide in the stream: about-site, following, also-on-rm, share-frontpage
 *                       Default: following
 *     'height' (int) - height of the iframe
 *                    Default: initial auto adjustable to 20 posts.
 * 
 * Usage: 
 * [rebelmouse site_name="rebelmouse"]
 * [rebelmouse site_name="rebelmouse" skip="about-site,following"]
 */
function rebelmouse_shortcode( $atts ) {
    extract( shortcode_atts( array(
        'site_name' => '',
        'sitename' => '',
        'cols' => 2,
        'skip' => 'following',
        'height' => '',
        'h' => '',
        'scroll' => 'auto',
        'width'=> '',
        'w'=> ''
    ), $atts ) );

    $rm_widget = new Rebelmouse_Widget();

    $width = (!empty($w))? $w: $widht;
    $height = (!empty($h))? $h: $height;
    $site_name= (!empty($sitename))? $sitename: $site_name;
    
    $rm_widget->render( array(
        'site_name' => $site_name,
        'cols' => $cols,
        'skip' => $skip,
        'height' => $height,
        'scroll' => $scroll,
        'width' => $width
    ) );
}
add_shortcode( 'rebelmouse', 'rebelmouse_shortcode' );

?>
